@@ -3,11 +3,12 @@ import os
 import sys
 import logging
 import argparse
+import warnings
 from decli import cli
 from pathlib import Path
 from configparser import RawConfigParser, NoSectionError
-from commitizen.application import Application
-from commitizen import deafults
+from commitizen import defaults, commands, out, config
+from commitizen.__version__ import __version__
 
 
 logger = logging.getLogger(__name__)
@@ -21,11 +22,7 @@ data = {
     "formatter_class": argparse.RawDescriptionHelpFormatter,
     "arguments": [
         {"name": "--debug", "action": "store_true", "help": "use debug mode"},
-        {
-            "name": ["-n", "--name"],
-            "default": deafults.NAME,
-            "help": "use the given commitizen",
-        },
+        {"name": ["-n", "--name"], "help": "use the given commitizen"},
         {
             "name": ["--version"],
             "action": "store_true",
@@ -38,27 +35,53 @@ data = {
             {
                 "name": "ls",
                 "help": "show available commitizens",
-                "func": lambda app: app.detected_cz,
+                "func": commands.ListCz,
             },
             {
                 "name": ["commit", "c"],
                 "help": "create new commit",
-                "func": lambda app: app.cz.run,
+                "func": commands.Commit,
             },
             {
                 "name": "example",
                 "help": "show commit example",
-                "func": lambda app: app.cz.show_example,
+                "func": commands.Example,
             },
             {
                 "name": "info",
                 "help": "show information about the cz",
-                "func": lambda app: app.cz.show_info,
+                "func": commands.Info,
             },
+            {"name": "schema", "help": "show commit schema", "func": commands.Schema},
             {
-                "name": "schema",
-                "help": "show commit schema",
-                "func": lambda app: app.cz.show_schema,
+                "name": "bump",
+                "help": "bump semantic version based on the git log",
+                "func": commands.Bump,
+                "arguments": [
+                    {
+                        "name": "--dry-run",
+                        "action": "store_true",
+                        "help": "show output to stdout, no commit, no modified files",
+                    },
+                    {
+                        "name": "--tag-format",
+                        "help": (
+                            "format used to tag the commmit and read it, "
+                            "use it in existing projects, "
+                            "wrap around simple quotes."
+                        ),
+                    },
+                    {
+                        "name": ["--prerelease", "-pr"],
+                        "help": "choose type of prerelease",
+                        "choices": ["alpha", "beta", "rc"],
+                    },
+                    {
+                        "name": ["--increment"],
+                        "help": "manually specify the desired increment",
+                        "choices": ["MAJOR", "MINOR", "PATCH"],
+                    },
+                ],
             },
         ],
     },
@@ -66,7 +89,7 @@ data = {
 
 
 def load_cfg():
-    settings = {"name": deafults.NAME}
+    settings = {"name": defaults.name}
     config = RawConfigParser("")
     home = str(Path.home())
 
@@ -78,12 +101,11 @@ def load_cfg():
     for cfg in configs:
         if not os.path.exists(config_file) and os.path.exists(cfg):
             config_file = cfg
-            break
 
         config_file_exists = os.path.exists(config_file)
         if config_file_exists:
             logger.debug('Reading file "%s"', config_file)
-            config.readfp(io.open(config_file, "rt", encoding="utf-8"))
+            config.read_file(io.open(config_file, "rt", encoding="utf-8"))
             log_config = io.StringIO()
             config.write(log_config)
             try:
@@ -97,25 +119,28 @@ def load_cfg():
 
 
 def main():
-    config = load_cfg()
+    conf = config.read_cfg()
     parser = cli(data)
 
     # Show help if no arg provided
     if len(sys.argv) == 1:
         parser.print_help(sys.stderr)
-        raise SystemExit(1)
+        raise SystemExit()
 
     args = parser.parse_args()
-    app = Application(**config)
 
     if args.name:
-        app.name = args.name
+        conf.update({"name": args.name})
 
     if args.debug:
+        warnings.warn(
+            "Debug will be deprecated in next major version. "
+            "Please remove it from your scripts"
+        )
         logging.getLogger("commitizen").setLevel(logging.DEBUG)
 
     if args.version:
-        logger.info(app.version)
-        sys.exit(0)
+        out.line(__version__)
+        raise SystemExit()
 
-    args.func(app)(args)
+    args.func(conf, vars(args))()
